
## CATO-CLI - query.licensing:
[Click here](https://api.catonetworks.com/documentation/#query-licensing) for documentation on this operation.

### Usage for query.licensing:

`catocli query licensing -h`

`catocli query licensing <json>`

`catocli query licensing "$(cat < licensing.json)"`

`catocli query licensing '{}'`

#### Operation Arguments for query.licensing ####
`accountId` [ID] - (required) N/A 
